import java.util.*;

public class ConcurrentModificationExample {
    public static void main(String[] args) {
        // Create a LinkedList of integers
        LinkedList<Integer> list = new LinkedList<>();
        list.add(1);
        list.add(2);
        list.add(3);
        list.add(4);

        System.out.println("Original List: " + list);

        // Bad removal: Throws ConcurrentModificationException
        try {
            Iterator<Integer> iterator = list.iterator();
            while (iterator.hasNext()) {
                Integer value = iterator.next();
                if (value % 2 == 0) {
                    list.remove(value);  // Direct removal causes exception
                }
            }
        } catch (ConcurrentModificationException e) {
            System.out.println("Exception caught during bad removal: " + e);
        }

        // Correct removal: Safe removal using iterator.remove()
        try {
            LinkedList<Integer> list2 = new LinkedList<>();
            list2.add(1);
            list2.add(2);
            list2.add(3);
            list2.add(4);

            Iterator<Integer> iterator2 = list2.iterator();
            while (iterator2.hasNext()) {
                Integer value = iterator2.next();
                if (value % 2 == 0) {
                    iterator2.remove();  // Correct removal using iterator's remove method
                }
            }

            System.out.println("List after correct removal: " + list2);  // Output: [1, 3]
        } catch (Exception e) {
            System.out.println("Exception caught during correct removal: " + e);
        }
    }
}

